@@ -9,12 +9,12 @@ compas_assembly
 .. toctree::
     :maxdepth: 1
 
-    compas_assembly.blender
+    compas_assembly.algorithms
+    compas_assembly.artists
     compas_assembly.datastructures
     compas_assembly.geometry
-    compas_assembly.ghpython
-    compas_assembly.plotter
     compas_assembly.rhino
+    compas_assembly.viewer
 
 """
 from __future__ import print_function
@@ -28,19 +28,20 @@ __copyright__ = "Block Research Group - ETH Zurich"
 __license__ = "MIT License"
 __email__ = "van.mele@arch.ethz.ch"
 
-__version__ = "0.4.3"
+__version__ = "0.5.0"
 
 
 HERE = os.path.dirname(__file__)
 HOME = os.path.abspath(os.path.join(HERE, "../../"))
 DATA = os.path.abspath(os.path.join(HOME, "data"))
 TEMP = os.path.abspath(os.path.join(HERE, "__temp"))
+SAMPLES = os.path.abspath(os.path.join(HERE, "data/samples"))
 
 
-__all__ = ["DATA", "TEMP"]
+__all__ = ["DATA", "TEMP", "SAMPLES"]
 __all_plugins__ = ["compas_assembly.install", "compas_assembly.rhino"]
 
 
 def get(filename):
     filename = filename.strip("/")
-    return os.path.abspath(os.path.join(DATA, filename))
+    return os.path.abspath(os.path.join(SAMPLES, filename))
